@@ -14,10 +14,12 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
+
 import re
+import sys
+from collections.abc import Generator, Iterable
 from os import getenv, path
-from os.path import basename, join, splitext
-from typing import TYPE_CHECKING, Any, Generator, Iterable, List, Optional, Tuple, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Optional, TypeVar, Union
 from unittest import TestCase
 from uuid import UUID
 
@@ -47,7 +49,7 @@ class SnapshotMixin:
 
     @staticmethod
     def getSnapshotFile(snapshot_name: str) -> str:  # noqa: N802
-        return join(SNAPSHOTS_DIRECTORY, f'{snapshot_name}.bin')
+        return path.join(SNAPSHOTS_DIRECTORY, f'{snapshot_name}.bin')
 
     @classmethod
     def writeSnapshot(cls, snapshot_name: str, data: str) -> None:  # noqa: N802
@@ -129,7 +131,7 @@ class DeepCompareMixin:
             self.assertEqual(0, len(d.dependencies), f'unexpected dependencies for {d.ref}')
 
 
-def reorder(items: List[_T], indexes: List[int]) -> List[_T]:
+def reorder(items: list[_T], indexes: list[int]) -> list[_T]:
     """
     Return list of items in the order indicated by indexes.
     """
@@ -185,8 +187,17 @@ def mksname(purpose: Union[Any], sv: SchemaVersion, f: OutputFormat) -> str:
     return f'{_get_purpose_as_str(purpose)}-{sv.to_version()}.{_SNAME_EXT[f]}'
 
 
-class DpTuple(Tuple[SchemaVersion, str]):
+class DpTuple(tuple[SchemaVersion, str]):
     @property
     def __name__(self) -> str:
         schema_version, test_data_file = self
-        return f'{schema_version.to_version()}-{splitext(basename(test_data_file))[0]}'
+        return f'{schema_version.to_version()}-{path.splitext(path.basename(test_data_file))[0]}'
+
+
+def load_pyproject() -> dict[str, Any]:
+    if sys.version_info >= (3, 11):
+        from tomllib import load as toml_load
+    else:
+        from tomli import load as toml_load
+    with open(path.join(path.dirname(__file__), '..', 'pyproject.toml'), 'rb') as f:
+        return toml_load(f)
