@@ -16,12 +16,12 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 
+from collections.abc import Generator, Iterable
 from enum import Enum
 from itertools import chain
 from json import load as json_load
-from typing import Any, Generator, Iterable, Tuple, Type
+from typing import Any
 from unittest import TestCase
-from unittest.mock import patch
 from warnings import warn
 from xml.etree.ElementTree import parse as xml_parse  # nosec B405
 
@@ -30,10 +30,11 @@ from ddt import ddt, idata, named_data
 from cyclonedx.exception import MissingOptionalDependencyException
 from cyclonedx.exception.serialization import SerializationOfUnsupportedComponentTypeException
 from cyclonedx.model import AttachedText, ExternalReference, HashType, XsUri
-from cyclonedx.model.bom import Bom
+from cyclonedx.model.bom import Bom, BomMetaData
 from cyclonedx.model.component import Component, Patch, Pedigree
 from cyclonedx.model.issue import IssueType
 from cyclonedx.model.license import DisjunctiveLicense
+from cyclonedx.model.lifecycle import LifecyclePhase, PredefinedLifecycle
 from cyclonedx.model.service import DataClassification, Service
 from cyclonedx.model.vulnerability import (
     BomTarget,
@@ -128,7 +129,7 @@ NAMED_OF_SV = tuple(
 
 class _EnumTestCase(TestCase, SnapshotMixin):
 
-    def _test_knows_value(self, enum: Type[Enum], value: str) -> None:
+    def _test_knows_value(self, enum: type[Enum], value: str) -> None:
         ec = enum(value)  # throws valueError if value unknown
         self.assertTrue(ec.name)  # TODO test for an expected name
 
@@ -165,7 +166,6 @@ class TestEnumDataFlow(_EnumTestCase):
         super()._test_knows_value(DataFlow, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(services=[Service(name='dummy', bom_ref='dummy', data=(
             DataClassification(flow=df, classification=df.name)
@@ -185,7 +185,6 @@ class TestEnumEncoding(_EnumTestCase):
         super()._test_knows_value(Encoding, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(components=[Component(name='dummy', type=ComponentType.LIBRARY, bom_ref='dummy', licenses=(
             DisjunctiveLicense(name=f'att.encoding: {encoding.name}', text=AttachedText(
@@ -206,7 +205,6 @@ class TestEnumExternalReferenceType(_EnumTestCase):
         super()._test_knows_value(ExternalReferenceType, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(components=[
             Component(name='dummy', type=ComponentType.LIBRARY, bom_ref='dummy', external_references=(
@@ -228,7 +226,6 @@ class TestEnumHashAlgorithm(_EnumTestCase):
         super()._test_knows_value(HashAlgorithm, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(components=[Component(name='dummy', type=ComponentType.LIBRARY, bom_ref='dummy', hashes=(
             HashType(alg=alg, content='ae2b1fca515949e5d54fb22b8ed95575')
@@ -248,7 +245,6 @@ class TestEnumComponentScope(_EnumTestCase):
         super()._test_knows_value(ComponentScope, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(components=(
             Component(bom_ref=f'scoped-{scope.name}', name=f'dummy-{scope.name}',
@@ -263,7 +259,7 @@ class _DP_ComponentType():  # noqa: N801
     JSON_SCHEMA_POINTER = ('definitions', 'component', 'properties', 'type')
 
     @classmethod
-    def unsupported_cases(cls) -> Generator[Tuple[str, OutputFormat, SchemaVersion, ComponentType], None, None]:
+    def unsupported_cases(cls) -> Generator[tuple[str, OutputFormat, SchemaVersion, ComponentType], None, None]:
         for name, of, sv in NAMED_OF_SV:
             if OutputFormat.XML is of:
                 schema_cases = set(dp_cases_from_xml_schema(SCHEMA_XML[sv], cls.XML_SCHEMA_XPATH))
@@ -287,7 +283,6 @@ class TestEnumComponentType(_EnumTestCase):
         super()._test_knows_value(ComponentType, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         if OutputFormat.XML is of:
             schema_cases = set(dp_cases_from_xml_schema(SCHEMA_XML[sv], _DP_ComponentType.XML_SCHEMA_XPATH))
@@ -324,7 +319,6 @@ class TestEnumPatchClassification(_EnumTestCase):
         super()._test_knows_value(PatchClassification, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(components=[
             Component(name='dummy', type=ComponentType.LIBRARY, bom_ref='dummy', pedigree=Pedigree(patches=(
@@ -346,7 +340,6 @@ class TestEnumImpactAnalysisAffectedStatus(_EnumTestCase):
         super()._test_knows_value(ImpactAnalysisAffectedStatus, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(vulnerabilities=[Vulnerability(
             bom_ref='dummy', id='dummy', affects=[BomTarget(ref='urn:cdx:bom23/1#comp42', versions=(
@@ -368,7 +361,6 @@ class TestEnumImpactAnalysisJustification(_EnumTestCase):
         super()._test_knows_value(ImpactAnalysisJustification, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(vulnerabilities=(
             Vulnerability(
@@ -391,7 +383,6 @@ class TestEnumImpactAnalysisResponse(_EnumTestCase):
         super()._test_knows_value(ImpactAnalysisResponse, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(vulnerabilities=[Vulnerability(
             bom_ref='dummy', id='dummy',
@@ -413,7 +404,6 @@ class TestEnumImpactAnalysisState(_EnumTestCase):
         super()._test_knows_value(ImpactAnalysisState, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(vulnerabilities=(
             Vulnerability(
@@ -435,7 +425,6 @@ class TestEnumIssueClassification(_EnumTestCase):
         super()._test_knows_value(IssueClassification, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(components=[
             Component(name='dummy', type=ComponentType.LIBRARY, bom_ref='dummy', pedigree=Pedigree(patches=[
@@ -459,7 +448,6 @@ class TestEnumVulnerabilityScoreSource(_EnumTestCase):
         super()._test_knows_value(VulnerabilityScoreSource, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(vulnerabilities=[Vulnerability(bom_ref='dummy', id='dummy', ratings=(
             VulnerabilityRating(method=vss)
@@ -479,10 +467,27 @@ class TestEnumVulnerabilitySeverity(_EnumTestCase):
         super()._test_knows_value(VulnerabilitySeverity, value)
 
     @named_data(*NAMED_OF_SV)
-    @patch('cyclonedx.model.ThisTool._version', 'TESTING')
     def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
         bom = _make_bom(vulnerabilities=[Vulnerability(bom_ref='dummy', id='dummy', ratings=(
             VulnerabilityRating(severity=vs)
             for vs in VulnerabilitySeverity
         ))])
         super()._test_cases_render(bom, of, sv)
+
+
+@ddt
+class TestEnumLifecyclePhase(_EnumTestCase):
+
+    @idata(set(chain(
+        dp_cases_from_xml_schemas(f"./{SCHEMA_NS}simpleType[@name='lifecyclePhaseType']"),
+        dp_cases_from_json_schemas('definitions', 'metadata', 'properties', 'lifecycles', 'items', 'phase'),
+    )))
+    def test_knows_value(self, value: str) -> None:
+        super()._test_knows_value(LifecyclePhase, value)
+
+    @named_data(*NAMED_OF_SV)
+    def test_cases_render_valid(self, of: OutputFormat, sv: SchemaVersion, *_: Any, **__: Any) -> None:
+        bom = _make_bom(metadata=BomMetaData(
+            lifecycles=[PredefinedLifecycle(phase=phase) for phase in LifecyclePhase]
+        ))
+        super()._test_cases_render(bom, of, sv)
