@@ -15,10 +15,10 @@
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
+from collections.abc import Generator
 from glob import iglob
 from itertools import chain
 from os.path import join
-from typing import Generator
 from unittest import TestCase
 
 from ddt import ddt, idata, unpack
@@ -31,17 +31,20 @@ from tests import OWN_DATA_DIRECTORY, SCHEMA_TESTDATA_DIRECTORY, DpTuple
 UNSUPPORTED_SCHEMA_VERSIONS = set()
 
 
-def _dp_sv_tf(prefix: str) -> Generator:
+def _dp_sv_tf(valid: bool) -> Generator:
+    prefix = 'valid-' if valid else 'invalid-'
     return (
-        DpTuple((sv, tf)) for sv in SchemaVersion if sv not in UNSUPPORTED_SCHEMA_VERSIONS
-        for tf in iglob(join(SCHEMA_TESTDATA_DIRECTORY, sv.to_version(), f'{prefix}-*.xml'))
+        DpTuple((sv, tf))
+        for sv in SchemaVersion if sv not in UNSUPPORTED_SCHEMA_VERSIONS
+        for tf in iglob(join(SCHEMA_TESTDATA_DIRECTORY, sv.to_version(), f'{prefix}*.xml'))
     )
 
 
-def _dp_sv_own() -> Generator:
+def _dp_sv_own(valid: bool) -> Generator:
     return (
-        DpTuple((sv, tf)) for sv in SchemaVersion if sv not in UNSUPPORTED_SCHEMA_VERSIONS
-        for tf in iglob(join(OWN_DATA_DIRECTORY, 'xml', sv.to_version(), '*.xml'))
+        DpTuple((sv, tf))
+        for sv in SchemaVersion if sv not in UNSUPPORTED_SCHEMA_VERSIONS
+        for tf in iglob(join(OWN_DATA_DIRECTORY, 'xml', sv.to_version(), '*.xml')) if ('invalid-' in tf) != valid
     )
 
 
@@ -60,8 +63,8 @@ class TestXmlValidator(TestCase):
             XmlValidator(schema_version)
 
     @idata(chain(
-        _dp_sv_tf('valid'),
-        _dp_sv_own()
+        _dp_sv_tf(True),
+        _dp_sv_own(True)
     ))
     @unpack
     def test_validate_no_none(self, schema_version: SchemaVersion, test_data_file: str) -> None:
@@ -74,7 +77,10 @@ class TestXmlValidator(TestCase):
             self.skipTest('MissingOptionalDependencyException')
         self.assertIsNone(validation_error)
 
-    @idata(_dp_sv_tf('invalid'))
+    @idata(chain(
+        _dp_sv_tf(False),
+        _dp_sv_own(False)
+    ))
     @unpack
     def test_validate_expected_error(self, schema_version: SchemaVersion, test_data_file: str) -> None:
         validator = XmlValidator(schema_version)
